#define MOZ_SOURCE_STAMP 1a8bbd6f7e2198f2ef47b603af80db405590aed4
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-release
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-release/rev/1a8bbd6f7e2198f2ef47b603af80db405590aed4
